@@ -4,10 +4,12 @@ from . import cloud_wanderer_resource
 from .cloud_wanderer import CloudWanderer
 from .aws_urn import AwsUrn
 from .custom_resource_definitions import CustomResourceDefinitions
+from .boto3_interface import CloudWandererBoto3Interface
 __all__ = [
     'storage_connectors',
     'cloud_wanderer_resource',
     'CloudWanderer',
     'AwsUrn',
-    'CustomResourceDefinitions'
+    'CustomResourceDefinitions',
+    'CloudWandererBoto3Interface'
 ]
